
;+ ***********************************************************************
; NAME:
;	LEC_NRH1D
;
; PURPOSE:
;	Cette procedure lit les images contenues dans un fichier FITS
;	au format NRH 1D
;
; CATEGORY:
;	NRH1 Fichier
;
; CALLING SEQUENCE:
;	LEC_NRH1D,Unit, Hd, Hf, Images
;, ARRAY=Array
;
; INPUTS:
;	UNIT	Unite logique de lecture. Le nom de fichier est dans
;		Fichinfo(unit).nomfich
;	HD	Heure de debut (hh:mn:ss:ccc)
;	HF	Heure de fin (hh:mn:ss:ccc)
;
; KEYWORD PARAMETERS:
;	ARRAY	Reseau 0:E-W, 1:N-S
;
; OUTPUTS:
;	IMAGES	Tableau d'images a 2 ou 3 Dimensions suivant que le motcle
;		'TYPE' contient:
;				'I'	lecture de I seul
;				'I+V' 	lecture de I et V
;		2 dimensions IMAGES(Espace,Temps)
;		3 dimensions IMAGES(Espace,Temps,I:V)
;
; COMMON BLOCKS:
;	NRH1_GLOBAL.
;
; MODIFICATION HISTORY: (bonmartin@obspm.fr)
;	12/11/98 Adapte du logiciel XHELIO (JB)
;-*******************************************************************

PRO LEC_NRH1D,n, Hd, Hf, Images, ARRAY=Array

COMMON NRH1_GLOBAL, Nomfich, Fichinfo

IF NOT KEYWORD_SET(ARRAY) THEN Array = 0

	INDID = TIME_IND_NRH( Fichinfo(n).nomfich, Hd)
	INDIF = TIME_IND_NRH( Fichinfo(n).nomfich, Hf)
	NPIX = Fichinfo(n).nbpix(0)
	
	IMAGES = FLTARR ( NPIX, (Indif-Indid)+1, 2 )

	FXBOPEN, Unit, Fichinfo(n).nomfich, 1
	HEADER = FXBHEADER (Unit)
		RC= String(13b)		;Retour chariot
	IF Array EQ 0 THEN BEGIN
	   IF MOTCLE(n, 'EAST_OUEST') NE 'Yes' THEN BEGIN
			R=WIDGET_MESSAGE('East-Ouest not exist')
	   RETURN & END
		COL= 3
	ENDIF

	TYPE = MOTCLE(n, 'TYPE')
	IF Array EQ 1 THEN BEGIN
	   IF MOTCLE(n, 'NORTH_SOUTH') NE 'Yes' THEN BEGIN
			R=WIDGET_MESSAGE('North-South not exist')
	   RETURN & END
		COL= 5
		IF Type EQ 'I' THEN COL=4
	        IF MOTCLE(n, 'EAST_OUEST') NE 'Yes' THEN COL = 3

	ENDIF

	FXBREAD, Unit, Iml, Col, [Indid+1, Indif+1]
		Images[*,*,0] = Iml
	IF Type EQ 'I+V' THEN BEGIN
		FXBREAD, Unit, Iml, Col+1, [Indid+1, Indif+1]
		Images[*,*,1] = Iml & END
	IF Type EQ 'I' THEN IMAGES = REFORM(Images[*,*,0])

	FXBCLOSE, Unit
	Iml = 0

END