
;+ ***********************************************************************
; NAME:
;	LIT_HEADER_NRH1
;
; PURPOSE:
;	Cette procedure est appelee par LITENTETE et remplit la structure
;	FILEINFO a partir des Headers d'un fichier FITS du NRH 1D
;
; CATEGORY:
;	NRH1 Fichier
;
; CALLING SEQUENCE:
;	 LIT_HEADER_NRH1, Fichier, Fileinfo
;
; INPUTS:
;	FICHIER	Nom du fichier
;
; KEYWORD PARAMETERS:
;	Non
;
; OUTPUTS:
;	FILEINFO	structure de type NRH1_FILEINFO
;
; COMMON BLOCKS:
;	NRH1_HELIO
;
; PROCEDURE:
;	Cette procedure remplit les champs de la structure FILEINFO, ainsi
;	que la partie texte (mot et valeurs) a partir des mots cles FITS
;

; MODIFICATION HISTORY: (bonmartin@obspm.fr)
;	Ecrit par: J Bonmartin le 13/11/98
;-*******************************************************************

PRO LIT_HEADER_NRH1, Fichier, Lreg, Fileinfo, Mots, Vals

common NRH1_HELIO,mainstruct

	HD0 = HEADFITS (Fichier)
	FXBOPEN ,UNIT, Fichier, 1, HD1


 FILEINFO = {NRH1_DFIXE_IM}

	Fileinfo.Nblocs = 0
	Fileinfo.Nbtete = 1
	Fileinfo.imint = 1
	Fileinfo.Nbpix(0) = FIX(STRCOMPRESS(FXPAR(Hd1, 'TFORM3')))

	Fileinfo.Nbaxes = 2
	Fileinfo.Orgint(0) = 0
	Fileinfo.Orgint(1) = 1
	Fileinfo.Valorg1 = $
		FLOAT ( HMS( FXPAR ( Hd1 , 'TIME_STR')))
	Fileinfo.paspix1 = FXPAR (Hd1,'EXPTIME')*1000.

;	Fileinfo.Tfich = 0
;	Fileinfo.tenre = 0
	Fileinfo.Heurdeb = HMS( FXPAR ( Hd1 , 'TIME_STR'))
	Fileinfo.heurfin = HMS( FXPAR ( Hd1 , 'TIME_END'))

		DATE = FXPAR ( Hd0, 'DATE-OBS')

		RESULT= STR_SEP(Date,'-')
	Fileinfo.Date(0) = Result(2)
	Fileinfo.Date(1) =result(1)
	Fileinfo.date(2) = Result(0)
		RC = STRING(13b)
	mots(0) = 'FREQ' & vals(0) = $
			STRING(FXPAR(Hd1, 'FREQ'),FORMAT='(F5.1)')+'-Mhz'
	mots(1) = 'UNIT' & vals(1) = 'SFU'
	mots(2) = 'LABEL' 
		IF Mainstruct.array EQ 0 THEN BEGIN
			Fileinfo.Paspix0 = FXPAR( Hd1, 'CDELT_EW')
			Fileinfo.Valorg0 = $
			    - (FXPAR ( Hd1, 'CRPIX1')) * Fileinfo.Paspix0
			vals(2) = 'EAST-WEST'
		ENDIF	ELSE BEGIN
			Fileinfo.Paspix0 = FXPAR( Hd1, 'CDELT_NS')
			Fileinfo.Valorg0 = $
			    - (FXPAR ( Hd1, 'CRPIX2')) * Fileinfo.Paspix0
			vals(2) = 'NORTH-SOUTH'
		ENDELSE
	mots(3) = 'INSTRUMENT' & vals(3) = 'RH'
	Fileinfo.Facbloc(1) = 1
	mots(4) ='TYPE'
	mots(5) = 'EAST_OUEST'
	mots(6) = 'NORTH_SOUTH'
		ERRMSG = ''
		ESI=FXBCOLNUM(Unit,'STOKESEI',ERRMSG=Errmsg)
			IF Esi NE 0 THEN vals(5) = 'Yes'
		NSI = FXBCOLNUM(Unit,'STOKESNI',ERRMSG=Errmsg)
			IF Nsi NE 0 THEN vals(6) = 'Yes'
		vals(4) = 'I'
		IF FXBCOLNUM(Unit,'STOKESEV',ERRMSG=Errmsg) NE 0 OR $
			FXBCOLNUM(Unit,'STOKESNV',ERRMSG=Errmsg) NE 0 $
		   THEN BEGIN
		          vals(4) = 'I+V'
			  Fileinfo.Facbloc(1) = 2
		ENDIF
	mots(7) = 'END'

	Fileinfo.Nbpix(1) = $
		FIX(STRCOMPRESS(FXPAR(Hd1, 'NAXIS2')))*Fileinfo.Facbloc(1)

	LREG = (Fileinfo.nbpix(0) + Fileinfo.nbtete) * 4

	FXBCLOSE, Unit

END 