
;+ ***********************************************************************
; NAME:
;	LITSEQ
;
; PURPOSE:
;	Cette fonction retourne le contenu d'un fichier NRH1 au format 
;	helio
;
; CATEGORY:
;	NRH1 ficchier
;
; CALLING SEQUENCE:
;	Image = LITSEQ( Unit, [Debut], [Fin])
;
; INPUTS:
;	UNIT	Unite de lecture associee au fichier
;
; OPTIONAL INPUTS:
;	DEBUT	Temps de debut en millisecondes dans la journee
;
;	FIN	Temps de fin em milli secondes dans la journee
;	
; KEYWORD PARAMETERS:
;	Non
;
; OUTPUTS:
;	IMAGE	Tableau contenant les images,
;			2 dim: [espace, temps] pour Stokes I
;			3 dim: [espace,I:V, temps]
;
; COMMON BLOCKS:
;	NRH1_GLOBAL
;
; MODIFICATION HISTORY: (bonmartin@obspm.fr)
;	16/11/98 adapte du logiciel XHELIO (JB)
;-*******************************************************************

FUNCTION LITSEQ, n, tempdb, tempfi

COMMON NRH1_GLOBAL,NomFich,FichInfo

IF N_PARAMS() EQ 0 THEN BEGIN
   Print, 'L''unite logique n''a pas ete specifie. '
   Print, ''                             
   MESSAGE,' erreur.'
ENDIF
IF N_ELEMENTS(tempfi) EQ 0 THEN tempfi=FichInfo(n).Heurfin
IF N_ELEMENTS(tempdb) EQ 0 THEN tempdb=FichInfo(n).Heurdeb 
t=0l
hchaine = ''
tempo = 0.0
NomFichier=NomFich(n)
;
hdeb= FLOAT(FichInfo(n).heurdeb)         ; convertion de l'heure de debut en reel
dt=FichInfo(n).paspix(1)                 ; Pas temporel entre deux images
numim1=LONG((tempdb-hdeb)/dt)            ; Indice de l'image dans le fichier
temps1=LONG(dt*(numim1)+hdeb)            ; Temps exact de l'image
;
hfin= FLOAT(FichInfo(n).heurfin)         ; convertion de l'heure de fin en reel
numim2=LONG((tempfi-hdeb)/dt)            ; Indice de l'image dans le fichier
temps2=LONG(dt*(numim2)+hdeb)            ; Temps exact de l'image
;
;
; Pointe sur la premiere image demandee
; 

;
OPENR, n, FichInfo(n).nomfich
;
;   Lecture des donnees demandees                                   
;
	Nbp=Fichinfo(n).Nbpix(0)
	Enti=Fichinfo(n).Nbtete
	Ente=Fichinfo(n).Nblocs*(nbp+Enti)*4 
	Nbl=Fichinfo(n).Nbpix(1)
	Nd=Fichinfo(n).Facbloc(1)

	Tempo=ASSOC(n,FLTARR(nbp+enti,nd,nbl/nd),Ente)
		Photo=Tempo(0)
		Image=Photo(Enti:Nbp+enti-1,*,0:nbl/nd-1)
;
CLOSE, n
return, image
END       

