
;+ ***********************************************************************
; NAME:
;	RUNMN_RH
;
; PURPOSE:
;	This procedure computes a running mean of a 1D RH-scan
;	At the border of the field of view use is made of the periodicity
;       of the scans.	
;
; CATEGORY:
;	NRH1 Positions
;
; CALLING SEQUENCE:
;	RUNMN_RH, scan, width, mscan, sdev
;
; INPUTS:
;	SCAN	original 1D scan 
;	WIDTH	number of points used for the computation of the mean	
;	
; KEYWORD PARAMETERS:
;	Non
;
; OUTPUTS:
;	MSCAN	array of running mean values (output)
;	SDEV	standard deviation of the fit (output)
;
; COMMON BLOCKS:
;	Non
;
; MODIFICATION HISTORY: (bonmartin@obspm.fr)
;	17/11/98	adapte du logiciel XHELIO
;-*******************************************************************

PRO RUNMN_RH, scan, width, mscan, sdev


npts = N_ELEMENTS(scan) & mscan = fltarr(npts)
nwid = long(width/2) & width = 2*nwid + 1
taby = fltarr(width)

for i = 0, npts-1 do begin
	ifirst = i - nwid & ilast = ifirst + width - 1
	if(ifirst ge 0 and ilast lt npts) then begin
		taby(0:width-1) = scan(ifirst:ilast)
	endif else if(ifirst lt 0) then begin
		taby(0:-ifirst-1) = scan(npts+ifirst:npts-1)
		taby(-ifirst:width-1) = scan(0:ilast)
	endif else if(ilast ge npts) then begin
		taby(0:npts-ifirst-1) = scan(ifirst:npts-1)
		taby(npts-ifirst:width-1) = scan(0:ilast-npts)
	endif 
	mscan(i) = total(taby)/width
endfor
sdev = SQRT( TOTAL( (scan - mscan)^2. ) / (npts-2) )
end
