
;+ ***********************************************************************
; NAME:
;	CPT_FLUX_NRH2
;
; PURPOSE:
;	Cette procedure calcule le flux correspondant a des images
; 2D du NRH
;
; CATEGORY:
;	Calculs NRH
;
; CALLING SEQUENCE:
;	CPT_FLUX_NRH2,file, Str_inf2d, Str_lim, Flux, Time
;
; INPUTS:
;	File	Nom du fichier
;	Str_inf2d	structure d'information de fichier
;	Str_lim structure contenant les limites de traitement (voir RH_2D)
;	
; KEYWORD PARAMETERS:
;	STOKES	calcul sur STOKESV si = 1, sur STOKESI si =0
;
; OUTPUTS:
;	FLUX	Tableau de flux
;	TIME	Tableau des temps
;	
; PROCEDURE:
;	Le calcul s'effectue sur une region  et d'une heure
; de debut et de fin determinees.
;	Par defaut les operations sont effectuees sur l'ensemble de l'image
; et du debut a la fin du fichier
;	Les operations sont effectuees image par image donc le volume du
; fichier ne constitue pas une limitation
;
; EXAMPLE:
;	Please provide a simple example here
;
; MODIFICATION HISTORY:
;	Ecrit par: J Bonmartin le 12/01/98 (bonmartin@obspm.fr)
;		Commence a l'indice I=0 le 04/07/01 (JB)
;-*******************************************************************

PRO CPT_FLUX_NRH2,file, Str_inf2d, Str_lim, Flux, Time, STOKES = stokes

IF NOT KEYWORD_SET (STOKES) THEN Stokes = 0

IF Str_inf2d.instrume EQ 'HSSI' THEN BEGIN
	Print,'Not available'
	RETURN & END

	TDEB = hms(str_lim.hd)
	TFIN = hms(str_lim.hf)



	NIM = Str_inf2d.nim
	FREQ = Str_inf2d.freq
	RAY = Str_inf2d.Ray

	DOMEGA = FLOAT(16 * 3E-4 /Ray)^2
	K = 0.138	;Cte de BOLTZMANN k=1.38e-23, pour avoir en SFU:K*e+22
	LAMDA = 300 / Freq
	FLUX1 = fltarr( nim )
	TIME1 = Lonarr( nim)

	J = 0
	I = 0
	REPEAT BEGIN
		RD_NRH2I,File,'',Str_inf2d,Data,Str_im, INDIC= I, $
					STOKES = Stokes
		I = I+1
	   TEMPS = Hms(Str_im.time)
	   IF Temps ge Tdeb THEN BEGIN
		Time1(j) = Temps
		Flux1(j)= TOTAL( REFORM(DATA(str_lim.xd:str_lim.xf, $
					str_lim.yd:str_lim.yf))) $ 
				*2*K*DOMEGA/Lamda^2
		J= J+1
	   END

	ENDREP UNTIL Nim LE I OR Temps GE Tfin

c=2*K*DOMEGA/Lamda^2
f=flux1(j-1)/(2*K*DOMEGA/Lamda^2)

	Time = WHERE( time1, count)
	If count NE 0 THEN Begin
		time= time1(0:count-1)
		flux= flux1(0:count-1)
	End

END
