;+ *************************************************************************************
; NAME:
;	PLOT_SOURCES
;
; PURPOSE:
;	Cette procedure affiche toutes les sources trouvees lors d'une recherche
;	de positions. Les sources sont classees par position.	
;
; CATEGORY:
;	RH_2D, recherche de positions
;
; CALLING SEQUENCE:
;	PLOT_SOURCES, Fichposi, IDWIN=IdW
;
; INPUTS:
;	Fichposi:	Fichier fits contenant les positions
;
; KEYWORD:
;	IDWIN:	numero de la fenetre (defaut: nouvelle fenetre)
;
; COMMON BLOCKS:
;	INFO2D, str_inf2d:	pour les coordonnees helio
;	VISU_2D,str_visu:	pour dimension de l'image
;	LIMIT,str_lim:		pour la region selectionnee
;
; MODIFICATION HISTORY:
;	Ecrit par: C Renie 17/03/1998
;	19/08/1998: on passe le nom d'un fichier fits de positions en parametre
;	16/10/1998: ajout du keyword IDWIN
;- *************************************************************************************


PRO plot_sources, fichposi, IDWIN=IdW
COMMON INFO2D, str_inf2d
COMMON VISU_2D,str_visu
COMMON LIMIT,str_lim

	; calcul des coordonnees heliographiques
	Xd = ind_rs(str_lim.Xd, str_inf2d.Xcen, str_inf2d.Ray)
	Xf = ind_rs(str_lim.Xf, str_inf2d.Xcen, str_inf2d.Ray)
	Yd = ind_rs(str_lim.Yd, str_inf2d.Ycen, str_inf2d.Ray)
	Yf = ind_rs(str_lim.Yf, str_inf2d.Ycen, str_inf2d.Ray)
	
	; recupere le nombre de positions figurant dans le fichier
	hprim = HEADFITS(fichposi)
	nbposi = FXPAR(hprim, 'N_EXTEND')
	cmpt = (nbposi-1)/6
	FOR i=0, cmpt DO BEGIN
	IF KEYWORD_SET(IdW) THEN WSET, IdW ELSE $
		WINDOW, /FREE, TITLE='Sources sorted in positions', $
		XSIZE=str_visu.dim, YSIZE=str_visu.dim
	position=[0.1, 0.1, 0.95*!D.X_VSIZE/!D.Y_VSIZE, 0.95]
	PLOT, [Xd, Xf], [Yd,Yf], /NODATA, XSTYLE=1, YSTYLE=1, POS=position
	OPLOT_CIRCLE, 1.
	IF ( (nbposi-6*i) GT 6 ) THEN lstpos = 6*i+5 ELSE lstpos = nbposi-1
	txt_leg = STRARR(lstpos-6*i+1)
	symb = INTARR(lstpos-6*i+1)
	FORnum=6*i, lstpos DO BEGIN
		txt_leg(num-6*i) = STRING(num, FORMAT='(I2)')
		; on evite les traces avec des points comme marque
		IF (num-6*i) GE 2 THEN symb(num-6*i) = num-6*i+2 ELSE symb(num-6*i) = num-6*i+1
		;t = MRDFITS(fichposi, num+1, hext, /SILENT)
		xmax = rdfilepos(fichposi, 'EWPOS', num+1)
		ymax = rdfilepos(fichposi, 'NSPOS', num+1)
		xmax = ind_rs(xmax, str_inf2d.Xcen, str_inf2d.Ray)
		ymax = ind_rs(ymax, str_inf2d.Ycen, str_inf2d.Ray)
		OPLOT, xmax, ymax, PSYM = symb(num-6*i)
             ENDFOR
;Now use AL_LEGEND in IDLAstro library (since LEGEND() was 
;               introduced in IDL 8.0)  may 2013
	AL_LEGEND, txt_leg, PSYM=symb, /RIGHT
	ENDFOR
END
