
;+ ***********************************************************************
; NAME:
;	WRITE_POSINRH
;
; PURPOSE:
;	Ecriture d'un fichier de positions au format FITS
;
; CATEGORY:
;	RH_2D, Recherche de position
;
; CALLING SEQUENCE:
;	WRITE_POSINRH, File, Fileimg, tabposi
;
; INPUTS:
;	File:		Nom du fichier de positions a ecrire
;	Fileimg:	Header primaire du fichier images
;	Tabposi:	Tableau de structure de type position
;
; MODIFICATION HISTORY:
;	Ecrit par: c. Reni 07/1998
;	04/1999: modification des keywords TIM_STR et TIM_END
;	07/2001: commentaires dans MAJAXIS, MINAXIS
;-*******************************************************************

PRO WRITE_POSINRH, File, Fileimg, tabposi

	r= FINDFILE(File)
	; cree un fichier vide si le fichier n'existe pas
	IF R(0) EQ '' THEN create_nrh_pfile, File, Fileimg
	; incremente le nombre d'extension dans le header primaire du fichier de position
	Hprimp = HEADFITS(File)
	NB_xtend = FXPAR(Hprimp, 'N_EXTEND') + 1
	FXHMODIFY, File, 'N_EXTEND', NB_xtend

	Header = HEADFITS(Fileimg, EXTEN=1)
	nbsource = (size(tabposi.temps))(1)
	SZ= (size(tabposi.source.max))(1)
	SXADDPAR, Header, 'TIM_STR', MSH(tabposi(0).temps)
	SXADDPAR, Header, 'TIM_END', MSH(tabposi(nbsource-1).temps)		
	SXDELPAR, Header, 'TFORM3'
	SXDELPAR, Header, 'TDIM3'
	SXDELPAR, Header, 'TTYPE3'
	IF FXPAR(Header, 'TFIELDS') EQ 4 THEN BEGIN
		SXDELPAR, Header, 'TFORM4'
		SXDELPAR, Header, 'TDIM4'
		SXDELPAR, Header, 'TTYPE4'
	ENDIF		
	SXDELPAR, Header, 'DATAMAX'
	SXDELPAR, Header, 'DATAMIN'
	SXADDPAR, Header, 'EWSTART', tabposi(0).source.xmax
	SXADDPAR, Header, 'NSSTART', tabposi(0).source.ymax
	SXADDPAR, Header, 'NAXIS1', nbsource*8*4
	SXADDPAR, Header, 'NAXIS2', 1
	SXADDPAR, Header, 'TFIELDS', 8
	SXADDPAR, Header, 'FILENAME', File
	SXADDPAR, Header, 'TFORM1', strcompress(string(sz),/REMOVE_ALL)+'J    '
	SXADDPAR, Header, 'TFORM2', strcompress(string(sz),/REMOVE_ALL)+'E    '
	SXADDPAR, Header, 'TTYPE2', 'INTENSITY'
	SXADDPAR, Header, 'TFORM3', strcompress(string(sz),/REMOVE_ALL)+'E    '
	SXADDPAR, Header, 'TTYPE3', 'EWPOS    '
	SXADDPAR, Header, 'TFORM4', strcompress(string(sz),/REMOVE_ALL)+'E    '
	SXADDPAR, Header, 'TTYPE4', 'NSPOS    '
	SXADDPAR, Header, 'TFORM5', strcompress(string(sz),/REMOVE_ALL)+'E    '
	SXADDPAR, Header, 'TTYPE5', 'MAJAXIS  ','Units: 1/ Npixels^2'
	SXADDPAR, Header, 'TFORM6', strcompress(string(sz),/REMOVE_ALL)+'E    '
	SXADDPAR, Header, 'TTYPE6', 'MINAXIS  ','Units: 1/ Npixels^2'
	SXADDPAR, Header, 'TFORM7', strcompress(string(sz),/REMOVE_ALL)+'E    '
	SXADDPAR, Header, 'TTYPE7', 'ANGLE    '
	SXADDPAR, Header, 'TFORM8', strcompress(string(sz),/REMOVE_ALL)+'E    '
	SXADDPAR, Header, 'TTYPE8', 'FLUX     '

	FXBHMAKE,Hb, 1
	FXBCREATE, Unit, File , Header
	FXBWRITE , Unit, tabposi.temps, 1,1
	FXBWRITE , Unit, tabposi.source.max, 2,1
	FXBWRITE , Unit, tabposi.source.xmax, 3,1
	FXBWRITE , Unit, tabposi.source.ymax, 4,1
	FXBWRITE , Unit, tabposi.source.gra, 5,1
	FXBWRITE , Unit, tabposi.source.grb, 6,1
	FXBWRITE , Unit, tabposi.source.tet, 7,1
	FXBWRITE , Unit, tabposi.flux, 8,1
	FXBFINISH, Unit

END
