;+ ***********************************************************************
; NAME: GET_STR_DP
;	
; PURPOSE:
;       Apres appel a rh_dpatchfits_nrh, on restaure toutes les
;       variables contenues dans la structure.
;
; CATEGORY:
;	Traitement de fichiers NRH
;
; INPUTS:  
;   structure regroupant tous les arguments d'appel necessaires au
;   calcul d'image.
;
; OUTPUTS:
;   tous les parametres contenus dans la structure
;
; MODIFICATION HISTORY:
; 01 oct    : - ecrit par: A. Bouteille
; 02 mar  5 : - ajout de sel_ant pour eliminer les antennes a problemes.
; 02 mar  7 : - ajout de crit_arret, larg_2 devient un fltarr(2)
;	 27 : - ajout de rot_p . 
; 03 jun 24 : - ajout des parametres de recalibration
;	    : - ----------------------- complement du pave central (recentrage)
; 04 sep 22 : - chgt de la recalibration manuelle : disparition de g_E2 etc,
;		  introduction de phi_ew_ns, g_flag, g_amp, g_phi .
; 05 fev  2 : - ajout de t_integ a la liste de sortie.	
; 05 fev  9 : - ajout de  phi_w_e  a la liste d'entree.
; 06 mar  3 : - ajout de une dimension sipplementaire (2) a phi_ew_ns, phi_w_e,
;		   g_amp, g_phi pour pouvoir corriger manuellement et simulta-
;		   nement non polar et polar. En fait la seule modif dans ce 
;		   programme est ce commentaire.
;	      - ajout de  i_affich_lobe  et  i_mul_pol  a la liste d'entree.
;
;-*******************************************************************

PRO GET_STR_DP, str_dp,	$
; OUTPUT
	version, i_simulation,                                       $ 
;     Temps d'integration prealable
	t_integ,						     $
;     Caracterisation de l'image
	n_period,  mode_interpol,  rot_p,  np,  larg,  t_b,	     $
	i_affich_lobe, i_mul_pol,				     $
;     Suppression (eventuelle) des harmoniques de certaines antennes
	ie0_ew,   ie0_ns,   ie1_ew,  ie2_ew,  ie2_ns,		     $
	ins45_ew,  ins45_ns, i_redond, gap_ns0, sel_ant,	     $
;     Cas particulier des sources de controle de calibration
	i_con_cal,					  	     $ ; ------
;     Correction de position d'antennes et recalibration
	i_corr_pos_ant,  i_recalib,  i_source_cal,   h_cal,  ch_cor, $ ; ------
	phi_ew_ns,  phi_w_e,  i_corr_g,  g_flag,  g_amp,  g_phi,     $
;     Complement du pave central (harm multiples impairs de 50m)
	i_pave_plein,	i_recentrage,  x_centrage,  y_centrage,      $
;     Calibration et clean
	mode_clean,  x_dom,  y_dom,  dr_dom,			     $
	i_ech_min,  i_ech_max ,  a_in,  a_ex,			     $
	a_red_fil,  itermax,  gain_iter,  jmax,	crit_arret,	     $
	i_seuil,  i_test_arret,  i_stop_image,  i_ecrete,  frac_ecr, $
	tete_fich,						     $
	fac_crois_res,	coeff_seuil, frac_flux,  		     $
	i_lissage,  poids_c, larg_2


	version		  = str_dp.version
	i_simulation	  = str_dp.i_simulation

        t_integ		  = str_dp.t_integ

        n_period	  = str_dp.n_period
        mode_interpol	  = str_dp.mode_interpol
	rot_p		  = str_dp.rot_p
        np		  = str_dp.np
        larg		  = str_dp.larg
        t_b		  = str_dp.t_b
        i_affich_lobe	  = str_dp.i_affich_lobe
        i_mul_pol	  = str_dp.i_mul_pol

        ie0_ew		  = str_dp.ie0_ew
        ie0_ns		  = str_dp.ie0_ns
        ie1_ew		  = str_dp.ie1_ew
        ie2_ew		  = str_dp.ie2_ew 
        ie2_ns		  = str_dp.ie2_ns
        ins45_ew	  = str_dp.ins45_ew 
        ins45_ns	  = str_dp.ins45_ns
        i_redond	  = str_dp.i_redond
        gap_ns0		  = str_dp.gap_ns0
	sel_ant		  = str_dp.sel_ant

	i_con_cal	  = str_dp.i_con_cal

	i_corr_pos_ant	  = str_dp.i_corr_pos_ant
        i_recalib	  = str_dp.i_recalib
        i_source_cal	  = str_dp.i_source_cal
        h_cal	  	  = str_dp.h_cal
	ch_cor		  = str_dp.ch_cor

	phi_ew_ns	  = str_dp.phi_ew_ns
	phi_w_e		  = str_dp.phi_w_e
	i_corr_g	  = str_dp.i_corr_g
	g_flag		  = str_dp.g_flag
	g_amp		  = str_dp.g_amp
	g_phi		  = str_dp.g_phi

        i_pave_plein	  = str_dp.i_pave_plein
	i_recentrage	  = str_dp.i_recentrage
	x_centrage	  = str_dp.x_centrage
	y_centrage	  = str_dp.y_centrage

        mode_clean	  = str_dp.mode_clean 
        x_dom		  = str_dp.x_dom 
        y_dom		  = str_dp.y_dom 
        dr_dom		  = str_dp.dr_dom 
        i_ech_min	  = str_dp.i_ech_min
        i_ech_max	  = str_dp.i_ech_max
        a_in		  = str_dp.a_in
        a_ex		  = str_dp.a_ex
        a_red_fil	  = str_dp.a_red_fil
        itermax		  = str_dp.itermax
        gain_iter	  = str_dp.gain_iter
        jmax		  = str_dp.jmax
        crit_arret	  = str_dp.crit_arret
        i_seuil		  = str_dp.i_seuil
        i_test_arret	  = str_dp.i_test_arret
        i_stop_image	  = str_dp.i_stop_image
        i_ecrete	  = str_dp.i_ecrete
        frac_ecr	  = str_dp.frac_ecr
        tete_fich	  = str_dp.tete_fich
        fac_crois_res	  = str_dp.fac_crois_res
        coeff_seuil	  = fltarr(3, 5)		 
        coeff_seuil(0, *) = str_dp.coeff_seuil0
        coeff_seuil(1, *) = str_dp.coeff_seuil1
        coeff_seuil(2, *) = str_dp.coeff_seuil2
        frac_flux	  = str_dp.frac_flux
        i_lissage	  = str_dp.i_lissage
        poids_c		  = str_dp.poids_c
        larg_2		  = str_dp.larg_2

        end
