PRO HDR_STR_DP, 	$
        str_dp,         $
	str_dp_hdr

;+ ***********************************************************************
; NAME: HDR_STR_DP
;	
; PURPOSE
;	Une structure reduite, qui sera ecrite dans le header du fichier fits 
;	d'images, est extraite de la structure contenant les arguments d'appel
;	de rh_dpatchfits_nrh.
;
; CATEGORY:
;	Traitement de fichiers NRH.
;
; INPUTS:  
;   str_dp :     Structure regroupant tous les arguments d'appel necessaires au
;   calcul d'image.
;
; OUTPUTS:
;   str_dp_hdr : Structure pour le header du fichier fits.
;
; MODIFICATION HISTORY:
; 01 oct    : ecrit par: A. Bouteille
; 02 mar  5 : - ajout de sel_ant pour eliminer les antennes a problemes.
; 02 mar  7 : - ajout de crit_arret, larg_2 devient un fltarr(2).
;	 27 : - ajout de rot_p . 
; 04 jan 12 : - ajout de g_AA1 etc aux listes des *STR_DP
;    jan 19 : - ajout de rh_common.inc    pour utiliser entfi.nbant
;    sep 22 : - chgt de la recalibration manuelle : disparition de g_E2 etc,
;		  introduction de phi_ew_ns, g_flag, g_amp, g_phi .
; 05 fev  9 : - ajout de  phi_w_e  a la liste d'entree.
; 06 mar  3 : - ajout de une dimension sipplementaire (2) a phi_ew_ns, phi_w_e,
;		   g_amp, g_phi pour pouvoir corriger manuellement et simulta-
;		   nement non polar et polar.
;	      - ajout de  i_affich_lobe  et  i_mul_pol.
; 06 avr  3 : - reduction de  ch_cor  a son noyau (ex : 14_nov_05_20:45)
 
;-*******************************************************************
	@rh_common.inc                  ;  pour utiliser entfi.nbant

        if (str_dp.mode_clean ne 0)  then  begin
            str_dp_hdr = {  	$ 
                version		: ' '     		,	$
                t_integ		: -1      		,	$
                n_period	: 1.      		,	$
                mode_interpol	: 0       		,	$
		rot_p		: 1       		,	$
                np		: 128     		,	$
                larg		: 4.      		,	$
                t_b		: 2       		,	$
                i_affich_lobe	: 1       		,	$
                i_mul_pol	: 1       		,	$

                ie0_ew		: 1   			,	$
                ie0_ns		: 1   			,	$
                ie1_ew		: 1   			,	$
                ie2_ew		: 0   			,	$
                ie2_ns		: 0   			,	$
                ins45_ew	: 1   			,	$
                ins45_ns	: 0   			,	$
		i_redond	: 1   			,	$
		suppress_ant	:' ' 			,       $

		i_con_cal	: 0			,	$

		i_corr_pos_ant	: 1			,	$
		i_recalib	: 0			,	$
		i_source_cal	: 1			,	$
		h_cal		: [20, 00]		,	$
		ch_cor		: ' '			,	$

		phi_ew_ns	: [0, 0]		,	$
		phi_w_e		: [0, 0]		,	$
		i_corr_g	: 0			,	$
		g_flag 		: replicate(0  , 48)	,	$
		g_amp 		: replicate(1.0, 48, 2)	,	$
		g_phi 		: replicate(0  , 48, 2)	,	$

                i_pave_plein	: 0       		,	$
		i_recentrage	: 0			,	$
		x_centrage	: 0.0			,	$
		y_centrage	: 0.0			,	$

                mode_clean	: 2       		,	$
                x_dom		: 0.      		,	$	
                y_dom		: 0.      		,	$
                dr_dom		: 0.      		,	$
                i_ech_min	: 0       		,	$
                i_ech_max	: 3       		,	$
                a_red_fil	: 0.99    		,	$
                itermax		: 1000    		,	$
                gain_iter	: 0.2     		,	$
                jmax		: 2      		,	$
                crit_arret	: [1, 1, 1, 0,   0, 0, 0],	$
                i_seuil		: [1,  2,  2 ,  2,  2]	,	$
                fac_crois_res	: 1.2        		,	$
                coeff_seuil0	: fltarr(5)  		,	$
                coeff_seuil1	: fltarr(5)  		,	$
                coeff_seuil2	: fltarr(5)  		,	$
                frac_flux	: 0.001      		,	$
                larg_2		: [20, 30]   			$
							  }
        end else begin
            str_dp_hdr = { 	$ 
                version		: ' '     		,	$
                t_integ		: -1      		,	$
                n_period	: 1.      		,	$
                mode_interpol	: 0       		,	$
		rot_p		: 1       		,	$
                np		: 128     		,	$
                larg		: 4.      		,	$
                t_b		: 2       		, 	$
                i_affich_lobe	: 1       		,	$
                i_mul_pol	: 1       		,	$

                ie0_ew		: 0       		,	$
                ie0_ns		: 0       		,	$
                ie1_ew		: 0       		,	$
                ie2_ew		: 0       		,	$
                ie2_ns		: 0       		,	$
                ins45_ew	: 0       		,	$
                ins45_ns	: 0       		,	$
		i_redond	: 0       		,	$
		suppress_ant	: ' '       		,	$

		i_con_cal	: 0			,	$

		i_corr_pos_ant	: 1			,	$
                i_recalib	: 0       		,	$
                i_source_cal	: 0       		,	$
                h_cal		: [20, 00]     		,	$
		ch_cor		: ' '			,	$

		phi_ew_ns	: [0, 0]		,	$
		phi_w_e		: [0, 0]		,	$
		i_corr_g	: 0			,	$
		g_flag 		: replicate(0  , 48)	,	$
		g_amp 		: replicate(1.0, 48, 2)	,	$
		g_phi 		: replicate(0  , 48, 2)	,	$

                i_pave_plein	: 0       		,	$
		i_recentrage	: 0			,	$
		x_centrage	: 0.0			,	$
		y_centrage	: 0.0			,	$

                mode_clean	: 0       			$
					                  }
        endelse

; Eclairage sur la suite : la structure str_dp_hdr contient les informations 
;   contenues dans le header du fichier d'image. 
	str_dp_hdr.version 	= str_dp.version
        str_dp_hdr.t_integ 	= str_dp.t_integ
        str_dp_hdr.n_period 	= str_dp.n_period
        str_dp_hdr.mode_interpol= str_dp.mode_interpol
	str_dp_hdr.rot_p	= str_dp.rot_p
        str_dp_hdr.np 		= str_dp.np
        str_dp_hdr.larg 	= str_dp.larg
        str_dp_hdr.t_b 		= str_dp.t_b
        str_dp_hdr.i_affich_lobe= str_dp.i_affich_lobe
        str_dp_hdr.i_mul_pol	= str_dp.i_mul_pol

        str_dp_hdr.ie0_ew 	= str_dp.ie0_ew
        str_dp_hdr.ie0_ns 	= str_dp.ie0_ns
        str_dp_hdr.ie1_ew 	= str_dp.ie1_ew
        str_dp_hdr.ie2_ew 	= str_dp.ie2_ew 
        str_dp_hdr.ie2_ns 	= str_dp.ie2_ns
        str_dp_hdr.ins45_ew 	= str_dp.ins45_ew 
        str_dp_hdr.ins45_ns 	= str_dp.ins45_ns
        str_dp_hdr.i_redond 	= str_dp.i_redond

        s1 =''
        del_ant = where( str_dp.sel_ant eq 0b, ncount)
        if ncount gt 0 then begin
           ch_ant = rh_antenne(entfi.nbant)
;        Precaution au cas on on tenterait de supprimer les AA dans une obser-
		; vation ou elles n'existent pas.
	   dom_permis = where(del_ant  le  entfi.nbant - 1, i_count)
	   if (i_count  gt  0) then  begin
		del_ant = del_ant(dom_permis)
       		for k = 0, i_count - 1  do begin
		    s1 = s1 + ' ' + ch_ant(del_ant(k))
		endfor
	   endif
        endif
        str_dp_hdr.suppress_ant = s1

	str_dp_hdr.i_con_cal	= str_dp.i_con_cal

	str_dp_hdr.i_corr_pos_ant	= str_dp.i_corr_pos_ant
	str_dp_hdr.i_recalib	= str_dp.i_recalib
	str_dp_hdr.i_source_cal	= str_dp.i_source_cal
	str_dp_hdr.h_cal	= str_dp.h_cal

;     Reduction de ch_cor a son "noyau", debarass'e du prefixe du directoire
	ch_cor = str_dp.ch_cor
;	pos_pref = strpos(ch_cor, '/', /reverse_offset, /reverse_search)
	    ; /reverse_offset  permet de rechercher la derniere occurence, ici
	    ;   le dernier "/". Ca n'a l'air de marcher que si on associe le 
	    ;	mot-cle "reverse_search".
	pos_pref = strpos(ch_cor, 'coeff_corr_', /reverse_search)
	    ; /reverse_search pour commencer a partir de la fin, mais le rang
	    ;	est compt'e a partir du debut.
	length = 15	; nbre de caracteres du noyau (ex : 14_nov_05_20:45)
	ch_cor_ini = strmid(ch_cor, pos_pref + 11, length)

;	str_dp_hdr.ch_cor	= str_dp.ch_cor	; avant 3 avril 2006
	str_dp_hdr.ch_cor	= ch_cor_ini	; apres 3 avril 2006

	str_dp_hdr.phi_ew_ns	= str_dp.phi_ew_ns
	str_dp_hdr.phi_w_e	= str_dp.phi_w_e
	str_dp_hdr.i_corr_g	= str_dp.i_corr_g
	str_dp_hdr.g_flag	= str_dp.g_flag
	str_dp_hdr.g_amp	= str_dp.g_amp
	str_dp_hdr.g_phi	= str_dp.g_phi

	str_dp_hdr.i_pave_plein = str_dp.i_pave_plein
	str_dp_hdr.i_recentrage	= str_dp.i_recentrage
	str_dp_hdr.x_centrage	= str_dp.x_centrage
	str_dp_hdr.y_centrage	= str_dp.y_centrage

        str_dp_hdr.i_recalib 	= str_dp.i_recalib

        str_dp_hdr.mode_clean 	= str_dp.mode_clean

        if (str_dp.mode_clean ne 0)  then begin
            str_dp_hdr.x_dom 		= str_dp.x_dom 
            str_dp_hdr.y_dom 		= str_dp.y_dom 
            str_dp_hdr.dr_dom 		= str_dp.dr_dom 
            str_dp_hdr.i_ech_min 	= str_dp.i_ech_min
            str_dp_hdr.i_ech_max 	= str_dp.i_ech_max
            str_dp_hdr.a_red_fil 	= str_dp.a_red_fil
            str_dp_hdr.itermax 		= str_dp.itermax
            str_dp_hdr.gain_iter 	= str_dp.gain_iter
            str_dp_hdr.jmax 		= str_dp.jmax
            str_dp_hdr.crit_arret 	= str_dp.crit_arret
            str_dp_hdr.i_seuil 		= str_dp.i_seuil
            str_dp_hdr.fac_crois_res 	= str_dp.fac_crois_res
            str_dp_hdr.coeff_seuil0 	= str_dp.coeff_seuil0
            str_dp_hdr.coeff_seuil1 	= str_dp.coeff_seuil1
            str_dp_hdr.coeff_seuil2 	= str_dp.coeff_seuil2
            str_dp_hdr.frac_flux 	= str_dp.frac_flux
            str_dp_hdr.larg_2 		= str_dp.larg_2
       endif
    end
