PRO RH_NORM_IM, champ_helio,  np,  domega_i,  freq,  $	; entree
	     anorm						; sortie

; Position du probleme:
;   . RH_MALC_IM_2D a produit une image de dimension npi (fig'e a 128) sur la 
;	grille des coordonnees interferometriques entieres normalisee de sorte
;	que son flux en sfu soit la somme de ses npi*npi pts (ce qui resulte 
;	simplement de l'usage de FFT).
;   . cette image est interpolee en np*np points correspondant a des coordon-
;	nees heliographiques sur une grille carree de pas  larg/np  (en general
;	larg=4Rs  et  np=128).

; Modifications :
; 01 jul 19	npi et np dans la liste d'arguments (au lieu de npew unique-
;		  ment). On tient compte dans anorm du fait que les images 
;		  interferometriques et heliographiques n'ont pas le meme nom-
;		  bre de points.
; 02 avr  3	reperage des "impressions genantes"
; 04 jun 18	devient un fichier independant car  RH_CALC_IMAGE_HELIO  n'est 
;		  plus le seul appelant, mais aussi RH_MALCROND_IM_2D
; 05 dec  2	la 1ere normalisation (si t_b = 1, on reste en sfu/pixels) est
;		  reportee en amont de RH_NORM_IM. Elle fait intervenir le
;		  rapport des totaux interfero et helio, et non le rapport
;		  domega_h / domega_i  comme c'etait le cas de facon erronee
;		  avant le 2 dec 2005. t_b est retire de la liste d'entree.
;		la 2eme normalisation (si t_b=2) est le seule qui reste dans 
;		  RH_NORM_IN. Elle est aussi corrigee.

;  RH_NORM_IM  n'est appele par RH_CALC_IMAGE_HELIO  que dans la cas ou on veut
;      obtenir une image en temperature de brillance. 
;    Il fournit en sortie le coeff multiplicatif anorm a appliquer a l'image 
;      heliographique (exprimee en sfu / pixel heliographique) pour obtenir des
;      kelvins.
;
;	rappel : on obtient le flux d'une image exprimee en sfu / pixels en
;		 faisant simplement lsa somme de ses points, sans multiplier
;		 par l'angle solide correspondant a un pixel.

; Notations:
; champ_helio	largeur du champ de l'image en coord heliographiques (Rs).
; npi		dimension de l'image interferometrique.
; np		-------------------- heliographique.
; domega_i	angle solide de la maille interferometrique (npi pts sur les
;		  champs interferometriques EW et NS.
; domega_h	angle solide de la maille heliographique carree (np pts sur
;		  "champ_helio".

    kB = 1.38E-23			; cste de Boltzmann.
    Rs = 4.65E-3			; 16' en radians. On neglige l'effet 
					;   de la variation annuelle.
    domega_h = (Rs * champ_helio / np)^2

; Cadavre de l'erreur trouvee le 2 dec 2005 (RH_NORM_IM  etait alors appele
;	pour t_b = 1 et 2)
;    if (t_b eq 1) then begin		; unites de brillance. Flux en sfu.
;	anorm = (domega_h / domega_i)
;    endif
;    if (t_b eq 2) then begin		; temp. de brillance en Kelvins.
;	lambda = 300. / freq		; en metres.
;	an1    = 1E-22 / domega_i	; an1 * (brillance interferometrique)
;					;   est en W m-2 sterad-1 Hz-1. 
;	anorm = an1 * lambda^2 / (2*kB) ; anorm * (brillance interferometrique)
;					;   est en Kelvins
;    endif
; Fin du cadavre

    lambda = 300. / freq		; en metres.
    an1    = 1E-22 / domega_h 
    anorm  = an1 * lambda^2 / (2 * kB) 	
	; anorm * (brillance interferometrique)  est en kelvins.
	; rem : le flux du cygne est 1e-22 a 164 pour les deux polarisations.
	;	Le RH acquiert une seule polar, pour le Cyge comme pour le 
	;       soleil. Comme on fait en sorte que le niveau des harmoniques 
	;	soit 1 et non 0.5, il faut donc pas omettre le facteur 2 devant
	;	kB.
	; A REVOIR ?

; Controle
    icon = 0
    if (icon eq 1) then begin
	d_i_8 = domega_i * 1E8
	d_h_8 = domega_h * 1E8
	a_i = sqrt(domega_i) * 180/!pi * 60
	a_h = sqrt(domega_h) * 180/!pi * 60
	print, 'RH_NORM_IM : '
	ch_format = "('    domega_i       =', f5.1, " + $
		"'    domega_h       =', f5.1, " + $
		"'      (10-8 sterad)')"    
	print, format=ch_format, d_i_8, d_h_8
	ch_format = "('    sqrt(domega_i) =', f5.2, " + $
		"'    sqrt(domega_h) =', f5.2, '      (arcmin)')"
	print, format=ch_format, a_i, a_h
	ch_format = "('    anorm =', g9.3)"
	print, format=ch_format, anorm 
	stop
    endif
; Fin de controle

    end					; fin de RH_NORM_IN.


;   cbri   = 1.43E-22 / domega			; 1.43=??  cadavre de Kerdraon.

; Reflexions :
; Soit B  la brillance de l'image heliographique du soleil, au sens photome-
;   trique du terme. Le flux dF d'un angle solide d_omega est :
;
;		dF = B * d_omega			(1)
;
; Supposons le soleil quadrill'e sur une grille a maille carree d'angle solide
;   d_omega_h (la grille dite "heliograpique"). On appelle B_h la brillance de
;   cette image "heliographique", normalisee de facon telle que le flux corres-
;   pondant a une region soit simplement la somme des points sur la region :
;
;		dF = sigma(B_h)
;							(2)
; On a evidemment :
;
;		B_h = B * d_omega_h			(3)
;
; Supposons maintenant l'image solaire connue sur une grille quelconque a 
;   mailles en parallellogramme (la grille interferometrique), d'angle solide
;   d_omega_i. 
;   On peut arbitairement disposer cette grille en carre, ce qui deforme le 
;   disque solaire, mais il est plus commode de garder le disque rond et de 
;   considerer une grille quelconque dessus. 
;   On appelle B_i la brillance de cette image ("interferometrique") normalisee
;   de facon telle que le flux correspondant a une region soit simplement la 
;   somme des points concernes. On a :
;
;		B_i = B * d_omega_i			(3)
;
;   On en deduit : 	B_i / d_omega_i  =   B_h / d_omega_h
;   soit :
;			B_h = B_i * (d_omega_h / d_omega_i)
;
; On voit que les dimensions des images "interferometriques" et "heliographi-
;   ques" de dependent pas explicitement des dimensions npi et np des images,
;   mais seulement a travers le rapport  (d_omega_h / d_omega_i) . Il n'est 
;   donc pas necessaire de passer npi a RH_NORM_IM si on passe d_omega_i. Par 
;   contre il faut passer "champ_helio" et "np" pour calculer d_omega_h .
;
; Si on remarque que c'est B_i qui est directement fourni par le calcul fft
;   on a tous les elements pour deduire B_h. 

; Fin de RH_NORM_IM

;______________________________________________________________________________


