
;+ ***********************************************************************
; NAME:
;	CW_PICKFILE_NRH
;
; PURPOSE:
;	Compound WIDGET for file selection
;	Use DIALOG_PICKFILE to select a file, and shows the name of the
;	selected file	
;
; CATEGORY:
;	Compound Widget
;
; CALLING SEQUENCE:
;	Result = CW_PICKFILE_NRH(Parent)
;
; INPUTS:
;	PARENT	ID of the parent widget
;	
; KEYWORD PARAMETERS:

;	REPERT	Path of the directory
;
;	FILTER	File filter
;
;	TITLE	Title of the widget
;
;	VALUE	Initial texte written in the widget
;
; OUTPUTS:
;	RESULT	ID of the created widget
;
;	On return the widget generates an event structure
;		ret = { ID:base, TOP:ev.top, HANDLER:0L, VALUE:file }
;
; COMMON BLOCKS:
;	No
;
; MODIFICATION HISTORY:	(bonmartin@obspm.fr)
;	12/11/98	Repris des programmes XHELIO (JB)
;-*******************************************************************

;*******************************************************

FUNCTION CW_PICKFILE_NRH_GET_VALUE,id,value

stash = WIDGET_INFO ( id , /CHILD )
WIDGET_CONTROL, stash, GET_UVALUE = state;,/NO_COPY
WIDGET_CONTROL, state.fichier, GET_VALUE = ret
WIDGET_CONTROL, stash, SET_UVALUE = state;,/NO_COPY
RETURN, ret(0)
END

;*********************************************************

PRO CW_PICKFILE_NRH_SET_VALUE,id,value

stash = WIDGET_INFO ( id , /CHILD )
WIDGET_CONTROL, stash, GET_UVALUE = state;,/NOCOPY
WIDGET_CONTROL, state.fichier, SET_VALUE=value
WIDGET_CONTROL, stash, SET_UVALUE = state;,/NOCOPY
END

;********************************************************
FUNCTION CW_PICKFILE_NRH_EVENT,ev

base = ev.handler                         ; we get back useful information 
stash = WIDGET_INFO ( base, /CHILD)       ; stored in the first child of
                                          ; the event handler
WIDGET_CONTROL, stash, GET_UVALUE = state;,/NO_COPY  

IF (ev.id EQ state.button) THEN BEGIN
   file = dialog_pickfile(GROUP=base, FILTER=state.filter, PATH = state.Repert)
   IF (file NE '') THEN $ 
   WIDGET_CONTROL,state.fichier,SET_VALUE=file
ENDIF

WIDGET_CONTROL,state.fichier,GET_VALUE=file

ret = { CW_PICKFILE_NRH_EVENT, ID:base, TOP:ev.top, $
        HANDLER:0L, VALUE:file}

WIDGET_CONTROL, stash, SET_UVALUE = state;,/NO_COPY

;       We send back an event with the new value
RETURN, ret
END

;********************************************************

; Another kind of compound widget : The pickfile Widget
;     version 1.00 by Rozier de Linage Manuel / efrei.fr

;*******************************************************
FUNCTION CW_PICKFILE_NRH,parent,VALUE = value, REPERT = Repert, $
                 TITLE = title, FILTER=filter

IF NOT KEYWORD_SET ( TITLE ) THEN title = 'File:'
IF NOT KEYWORD_SET ( VALUE ) THEN value = ''
IF NOT KEYWORD_SET ( REPERT ) THEN Repert = ''
IF NOT KEYWORD_SET ( FILTER ) THEN filter = '*' ;	modif 10/11/98

           
base = WIDGET_BASE ( parent, $
                     EVENT_FUNC = 'CW_PICKFILE_NRH_EVENT', $
                     FUNC_GET_VALUE = 'CW_PICKFILE_NRH_GET_VALUE', $
                     PRO_SET_VALUE = 'CW_PICKFILE_NRH_SET_VALUE', $
                     /ROW,/FRAME)

fichier = CW_FIELD(base, TITLE = title, $
              VALUE = value, xsize=40, /RETURN_EVENTS, /STRING)


;     bitmap of the file button

design =  [$
                [000B, 015B],$                       
                [128B, 025B],$                       
                [192B, 048B],$                      
                [064B, 032B],$                       
                [064B, 032B],$                       
                [000B, 248B],$                       
                [255B, 119B],$                       
                [001B, 036B],$                      
                [001B, 004B],$                       
                [001B, 004B],$                     
                [225B, 255B],$                       
                [017B, 128B],$                      
                [009B, 064B],$        
                [005B, 032B],$
                [003B, 016B],$
                [255B, 015B] $
                ]
                 

button = WIDGET_BUTTON(base,VALUE=design)


;    We store useful information in the state variable to avoid COMMONs.

state = { button : button, value : value , fichier:fichier , $
		Repert: Repert, filter : filter}

WIDGET_CONTROL, WIDGET_INFO ( base, /CHILD ), SET_UVALUE = state;,/NO_COPY

RETURN, base      ; A compound widget always return is main base id.
END


