
;+ ***********************************************************************
; NAME:
;	NRH_PLOTF
;
; PURPOSE:
;	Cette procedure trace le flux d'une frequence donnee poor les fichiers
;	des routines NRH. Noms des fichiers
;		nrot*.fts ou nrin*.fts
;
; CATEGORY:
;	NRH Routines
;
; CALLING SEQUENCE:
;	NRH_PLOTF, Fichier, Frequence
;
; INPUTS:
;	FICHIER		nom du fichier
;	FREQUENCE	Indice de la frequence a tracer
;	
; KEYWORD PARAMETERS:
;	HR_BEG		Heure de debut de trace 'hhmmsscc'
;	HR_END		Heure de fin de trace
;	OPLOT		Oplot IDL
;	INDICE 		Indice du trace dans la fenetre, la couleur du
;			trace est fonction de cet indice (valeurde 0 a 10)
;			voit NRHR_COLOR_PLOT
;	YRANGE		Echelle en Y, TABLEAU=[MIN,MAX]
;	YLOG		Trace en LINEAIRE si present
;	XLAB		chaine de label de l'axe X
;	PSYM		PSYM IDL
;	BACKGROUND	Indice de la couleur du fond 
;	NOCOLOR		Trace en Noir et Blanc
;	RED, GREEN, BLUE	Tables de couleur du trace
;
;
; OUTPUTS:
;	
;
; OPTIONAL OUTPUTS:
;	
; COMMON BLOCKS:
;	
;
; SIDE EFFECTS: NRHR_PLOTF modifie la table de couleur, celle-ci est
;	restituee en sortie de NRHR
;
; RESTRICTIONS:
;
; PROCEDURE:
;
; EXAMPLE:
;
; MODIFICATION HISTORY:
;	Ecrit par:Jean.Bonmartin@obspm.fr
;	Ajustement des niveaux pour donnees calibrees le 07/11/01 (JB)
;-*******************************************************************

PRO NRHR_PLOTF,File,IdFreq, HR_BEG = Hr_beg, HR_END= Hr_end, $
	OPLOT=Oplot, INDICE=Indice, YRANGE = Yrange, YLOG = Ylog, $
	XLAB = Xlab, PSYM = Psym, BACKGROUND= Background, $
	NOCOLOR=Nocolor, RED= Red_p, GREEN=Green_p, BLUE=Blue_p

	DATE= STRMID(File,STRLEN(File)-19,8)

	IF NOT KEYWORD_SET(COLOR) THEN Color='WHITE'
	IF NOT KEYWORD_SET(INDICE) Then Indice= 0
	IF NOT KEYWORD_SET(OPLOT) THEN BEGIN
		IF NOT KEYWORD_SET(YRANGE) THEN YRANGE=[0,5]
		Oplot=0 & Indice=0 & ENDIF
	IF NOT KEYWORD_SET(HR_BEG) THEN Hr_beg = 0
	IF NOT KEYWORD_SET(HR_END) THEN Hr_end = 0
	IF NOT KEYWORD_SET(BACKGROUND) THEN Background = 0
	IF NOT KEYWORD_SET(XLAB) THEN Xlab= 'Time (UT)'+ $
	  '   '+STRMID(Date,0,4)+'/'+STRMID(Date,4,2)+'/'+STRMID(Date,6,2)
	IF NOT KEYWORD_SET(YLAB) THEN Ylab = 'FLUX'

	HD0 = HEADFITS(File)
	LF = NRHR_LFREQ(HD0)
	FREQ = Lf[Idfreq]

	Spec = MRDFITS(File,1,HD,/SILENT)

	Backg=1 & Couleur=1
IF KEYWORD_SET (NOCOLOR) THEN BEGIN
		Backg=1 & Couleur=0
ENDIF ELSE NRH_COLOR_PLOT,Red_p,Green_p,blue_p,RED=R,GREEN=G,BLUE=B, /ROUT

IF FXPAR(HEADFITS(File),'CALIB') EQ 1 THEN BEGIN
		YRANGE=[1000.,10.^8] & YLOG=0
	ENDIF ELSE BEGIN
		YRANGE=[0.1,5] & YLOG=1
	ENDELSE

TR_TIME_NRH, Spec.Frq[IdFreq],Spec.time,YLOG=Ylog, YRANGE= Yrange, $
		CLAB=' '+STRCOMPRESS(STRING(Freq),/REMOVE_ALL)+' MHz', $
		OPLOT=Oplot, LINESTYLE=Indice,$
		HR_BEG=Hr_beg,HR_END=hr_end, PSYM= Psym, $
		XLAB=Xlab, YLAB = Ylab, $
		BACKGROUND=Backg,Color=Couleur

END

